function [D0_cm2s,Ea,Va,Pref] = diff_system(name_sys)
kcal2kj = 4.1868;
%Available Systems (see below for references)
%Muscovite 1 & 2
%Hornblende 1 & 2
%Biotite 1 & 2 & 3 & 4
%Orthoclase
if strcmp(name_sys,'Muscovite1')==1
    %Data from Harrison et al. 2009 Geoch - Cosm Acta
    %fitted using sph. geometry and grain size range 24 (most) to 87 microns
    D0_cm2s     = 2.3;               %Pre-exponent factor
    Ea          = 263*1e3;           %Activation Energy in j/mol
    Va          = 14;                %Activation volume in cm3, P in MPa
    Pref        = 1000;              %Reference Pressure (MPa) for PV term
elseif strcmp(name_sys,'Muscovite2')==1
    %as in Lister and Baldwin 1999 (Tectonophysics)
    %used for slab geometry and half thickness of 5.9 microns
    %Original data from Robbins (1972, MSc Thesis, State .Univ. NY at Albany)
    D0_cm2s     = 3.35*1e-7;         %Pre-exponent factor
    Ea          = 41.8*kcal2kj*1e3;  %Activation Energy in j/mol
    Va          = 10;                %Activation volume in cm3, P in MPa
    Pref        = 1e-4;              %Reference pressure in MPa
elseif strcmp(name_sys,'Hornblende1')==1
    %Experimental Set from Harrison 1982 Contrib Mineral Petrol
    %This is only the experimental set and not the final
    %expression suggested by the author
    %Activation volume correction after Lister and Baldwin 1996
    %(used for 80 microns and spherical geometry)
    D0_cm2s     = 0.061;             %Pre-exponent factor
    Ea          = 66.1*kcal2kj*1e3;  %Activation Energy in j/mol
    Va          = 10;                %Activation volume in cm3, P in MPa
    Pref        = 1e-4;              %Reference Pressure (MPa) for PV term
elseif strcmp(name_sys,'Hornblende2')==1
    %Harrison 1982 Contrib Min Petrol (parameters as suggested by author)
    %Activation volume correction after Lister and Baldwin 1996
    %(used for 80 microns abd spherical geometry)
    D0_cm2s     = 0.024;             %Pre-exponent factor
    Ea          = 64.1*kcal2kj*1e3;  %Activation Energy in j/mol
    Va          = 10;                %Activation volume in cm3, P in MPa
    Pref        = 1e-1;              %Reference Pressure (MPa) for PV term
elseif strcmp(name_sys,'Biotite1')==1
    %Original data from Grove and Harrison 1996 (Am Mineral)
    %Data for Fe-Biotite (Xann = 0.71)
    %Activation volume is not considered
    D0_cm2s     = 0.40;              %Pre-exponent factor
    Ea          = 50.5*kcal2kj*1e3;  %Activation Energy
    Va          = 0;                 %Originally 0, Skipton et al. (2018) used 14 as in Harrison et al. (2009)
    Pref        = 1e-4;              %Reference Pressure (MPa) for PV term
elseif strcmp(name_sys,'Biotite2')==1
    %as used in Lister and Baldwin 1996
    %Original data from Harrison et al. 1985 (Geochim Cosmochim Acta)
    %Activation volume correction after Lister and Baldwin 1996
    %(used for 150 microns and cylindrical geometry)    
    D0_cm2s     = 0.077;             %Pre-exponent factor
    Ea          = 47*kcal2kj*1e3;    %Activation Energy
    Va          = 10;                %Originally 0, Skipton et al. (2018) used 14 as in Harrison et al. (2009)
    Pref        = 1e-4;              %Reference Pressure (MPa) for PV term
elseif strcmp(name_sys,'Biotite3')==1
    %Original data from Giletti 1974 (as reported in McDougal & Harrison 1999)
    %Data for Phlogopite (Xann = 0.04)
    %Activation volume correction after Lister and Baldwin 1996
    %(used for 150 microns and cylindrical geometry) 
    D0_cm2s     = 0.75;              %Pre-exponent factor
    Ea          = 57.9*kcal2kj*1e3;  %Activation Energy
    Va          = 10;                %Originally 0
    Pref        = 1e-4;              %Reference Pressure (MPa) for PV term    
elseif strcmp(name_sys,'Biotite4')==1
    %Original data from Grove and Harrison 1996 (Am Mineral)
    %Data for Cooma biotite (Xann = 0.54)
    D0_cm2s     = 0.075;             %Pre-exponent factor
    Ea          = 47.1*kcal2kj*1e3;  %Activation Energy
    Va          = 0;                 %not considered
    Pref        = 1e-4;              %Reference Pressure (MPa) for PV term
elseif strcmp(name_sys,'Orthoclase')==1
    %Original data from Foland 1993
    D0_cm2s     = 0.00982;           %Pre-exponent factor
    Ea          = 43.8*kcal2kj*1e3;  %Activation Energy
    Va          = 0;                 %not considered
    Pref        = 1e-4;              %Reference Pressure (MPa) for PV term
elseif strcmp(name_sys,'custom')==1
    load Custom_Diff.dat
    D0_cm2s     = Custom_Diff(1);    %Value in cm2/sec
    Ea          = Custom_Diff(2);    %in kj/mol
    Va          = Custom_Diff(3);    %in cm3
    Pref        = Custom_Diff(4);    %in MPa
else
    error('Unknown mineral system')
end
end
